@@ -1,3 +1,4 @@
+import os
 import unittest
 
 from transformers import BertTokenizer, AutoTokenizer
@@ -6,26 +7,33 @@ import tfkit
 
 
 class TestDataLoader(unittest.TestCase):
+    ROOT_DIR = os.path.dirname(os.path.abspath(__file__ + "/../"))
+    DATASET_DIR = os.path.join(ROOT_DIR, 'demo_data')
 
     def testTagRow(self):
-        for i in tfkit.tag.get_data_from_file_row('../demo_data/tag_row.csv'):
+        for i in tfkit.tag.get_data_from_file_row(os.path.join(TestDataLoader.DATASET_DIR, 'tag_row.csv')):
             print(i)
-        for i in tfkit.tag.loadRowTaggerDataset('../demo_data/tag_row.csv', pretrained='bert-base-chinese', maxlen=128):
+        for i in tfkit.tag.loadRowTaggerDataset(os.path.join(TestDataLoader.DATASET_DIR, 'tag_row.csv'),
+                                                pretrained='bert-base-chinese', maxlen=128):
             self.assertTrue(len(i['input']) < 512)
             self.assertTrue(len(i['target']) < 512)
 
     def testTagCol(self):
-        for i in tfkit.tag.get_data_from_file_col('../demo_data/tag_col.csv'):
+
+        for i in tfkit.tag.get_data_from_file_col(os.path.join(TestDataLoader.DATASET_DIR, 'tag_col.csv')):
             print(i)
-        for i in tfkit.tag.loadColTaggerDataset('../demo_data/tag_col.csv', pretrained='bert-base-chinese', maxlen=128):
+        for i in tfkit.tag.loadColTaggerDataset(os.path.join(TestDataLoader.DATASET_DIR, 'tag_col.csv'),
+                                                pretrained='bert-base-chinese', maxlen=128):
             self.assertTrue(len(i['input']) < 512)
             self.assertTrue(len(i['target']) < 512)
 
     def testOnce(self):
+
         tokenizer = BertTokenizer.from_pretrained('bert-base-chinese')
-        for i in tfkit.gen_once.get_data_from_file('../demo_data/generate.csv'):
+        for i in tfkit.gen_once.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv')):
             print(i)
-        for i in tfkit.gen_once.loadOnceDataset('../demo_data/generate.csv', pretrained='bert-base-chinese',
+        for i in tfkit.gen_once.loadOnceDataset(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv'),
+                                                pretrained='bert-base-chinese',
                                                 maxlen=128):
             print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['input'])))
             print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['target'])))
@@ -34,11 +42,13 @@ class TestDataLoader(unittest.TestCase):
 
     def testOnebyone(self):
         tokenizer = BertTokenizer.from_pretrained('bert-base-cased')
-        for i in tfkit.gen_onebyone.get_data_from_file('../demo_data/generate.csv'):
+
+        for i in tfkit.gen_onebyone.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv')):
             print(i)
         maxlen = 512
         for likelihood in ['onebyone-neg', 'onebyone-pos', 'onebyone-both']:
-            for i in tfkit.gen_onebyone.loadOneByOneDataset('../demo_data/generate.csv', pretrained='bert-base-cased',
+            for i in tfkit.gen_onebyone.loadOneByOneDataset(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv'),
+                                                            pretrained='bert-base-cased',
                                                             maxlen=maxlen, likelihood=likelihood):
                 # print(likelihood, i)
                 print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['input'])))
@@ -57,7 +67,8 @@ class TestDataLoader(unittest.TestCase):
         maxlen = 512
         for likelihood in ['onebyone', 'onebyone-neg', 'onebyone-pos', 'onebyone-both']:
             output = []
-            for i in tfkit.gen_onebyone.loadOneByOneDataset('../demo_data/generate.csv', pretrained='openai-gpt',
+            for i in tfkit.gen_onebyone.loadOneByOneDataset(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv'),
+                                                            pretrained='openai-gpt',
                                                             maxlen=maxlen, likelihood=likelihood):
                 start_pos = i['start']
                 output.append(tokenizer.convert_ids_to_tokens(i['target'])[start_pos])
@@ -65,24 +76,25 @@ class TestDataLoader(unittest.TestCase):
             print(tokenizer.convert_tokens_to_string(output) + "\n")
 
     def testClassifier(self):
-        for i in tfkit.classifier.get_data_from_file('../demo_data/classification.csv'):
+
+        for i in tfkit.classifier.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'classification.csv')):
             print(i)
-        for i in tfkit.classifier.loadClassifierDataset('../demo_data/classification.csv',
+        for i in tfkit.classifier.loadClassifierDataset(os.path.join(TestDataLoader.DATASET_DIR, 'classification.csv'),
                                                         pretrained='bert-base-chinese',
                                                         maxlen=512):
             self.assertTrue(len(i['input']) <= 512)
             self.assertTrue(len(i['target']) < 512)
 
     def testQA(self):
-        for i in tfkit.qa.get_data_from_file('../demo_data/qa.csv'):
+        for i in tfkit.qa.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv')):
             print(i)
-        for i in tfkit.qa.loadQADataset('../demo_data/qa.csv',
+        for i in tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
                                         pretrained='bert-base-chinese',
                                         maxlen=512):
             print(i['raw_input'][int(i['target'][0]):int(i['target'][1])])
             self.assertTrue(len(i['input']) <= 512)
             self.assertTrue(len(i['target']) == 2)
-        for i in tfkit.qa.loadQADataset('../demo_data/qa.csv',
+        for i in tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
                                         pretrained='voidful/albert_chinese_tiny',
                                         maxlen=512):
             print(i['raw_input'][int(i['target'][0]):int(i['target'][1])])
@@ -90,14 +102,14 @@ class TestDataLoader(unittest.TestCase):
             self.assertTrue(len(i['target']) == 2)
 
     def testLen(self):
-        ds = tfkit.qa.loadQADataset('../demo_data/qa.csv',
+        ds = tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
                                     pretrained='bert-base-chinese',
                                     maxlen=512)
         print(ds.__len__())
         ds.increase_with_sampling(20)
         self.assertTrue(ds.__len__() == 20)
 
-        ds = tfkit.qa.loadQADataset('../demo_data/qa.csv',
+        ds = tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
                                     pretrained='bert-base-chinese',
                                     maxlen=512)
         print(ds.__len__())
